;***************************************************************************
;* A P P L I C A T I O N   N O T E   F O R   T H E   P S L I   F A M I L Y
;* 
;* File Name:           AT94KDEF.INC
;* Title:               Register/Bit Definitions for the AT94K
;* Version:             1.0.2
;* Last Updated:        October 8, 2001
;* Support Hotline:     +1 (408) 436-4119
;* Support Email:       fpslic@atmel.com
;* Target Device:       AT94K05/10/40
;*
;* DESCRIPTION
;* When including this file in the assembly program file, all I/O register      
;* names and I/O register bit names appearing in the data book can be used.
;* In addition, the six registers forming the three data pointers X, Y and
;* Z have been assigned names XL - ZH.  Highest RAM address for Internal
;* SRAM is also defined, for all possible combinations.
;*
;* The Register names are represented by their hexadecimal address.
;* 
;* The Register Bit names are represented by their bit number (0-7).
;* 
;* Please observe the difference in using the bit names with instructions
;* such as "sbr"/"cbr" (set/clear bit in register) and "sbrs"/"sbrc" 
;* (skip if bit in register set/cleared). The following example illustrates
;* this:
;* 
;* in   r16, PORTD              ;Read PORTD latch
;* sbr  r16, (1<<PD6)+(1<<PD5)  ;Set PD6 and PD5 (Use Masks not Bit #)
;* out  PORTD, r16              ;Output to PORTD
;*
;* in   r16, TIFR               ;Read the Timer Interrupt Flag Register
;* sbrc r16, TOV0               ;Test the Overflow Flag (Use Bit #)
;* rjmp TOV0_SET                ;Jump if Set
;* ...                          ;Otherwise Continue from Here
;***************************************************************************



;***************************************************************************
;*                              Specify Device                             
;***************************************************************************

.device AT94K



;***************************************************************************
;*                        I/O Register Definitions                         
;***************************************************************************

.equ    SREG            = $3F
.equ    SPH             = $3E
.equ    SPL             = $3D
.equ    EIMF            = $3B
.equ    SFTCR           = $3A
.equ    TIMSK           = $39
.equ    TIFR            = $38
.equ    TWCR            = $36
.equ    MCUR            = $35
.equ    TCCR0           = $33
.equ    TCNT0           = $32
.equ    OCR0            = $31
.equ    SFIOR           = $30
.equ    TCCR1A          = $2F
.equ    TCCR1B          = $2E
.equ    TCNT1H          = $2D
.equ    TCNT1L          = $2C
.equ    OCR1AH          = $2B
.equ    OCR1AL          = $2A
.equ    OCR1BH          = $29
.equ    OCR1BL          = $28
.equ    TCCR2           = $27
.equ    ASSR            = $26
.equ    ICR1H           = $25
.equ    ICR1L           = $24
.equ    TCNT2           = $23
.equ    OCR2            = $22
.equ    WDTCR           = $21
.equ    UBRRHI          = $20
.equ    TWDR            = $1F
.equ    TWAR            = $1E
.equ    TWSR            = $1D
.equ    TWBR            = $1C
.equ    FPGAD           = $1B
.equ    FPGAZ           = $1A
.equ    FPGAY           = $19
.equ    FPGAX           = $18
.equ    FISUD           = $17
.equ    FISUC           = $16
.equ    FISUB           = $15
.equ    FISUA           = $14
.equ    FISCR           = $13
.equ    PORTD           = $12
.equ    DDRD            = $11
.equ    PIND            = $10
.equ    UDR0            = $0C
.equ    UCSR0A          = $0B
.equ    UCSR0B          = $0A
.equ    UBRR0           = $09
.equ    PORTE           = $07
.equ    DDRE            = $06
.equ    PINE            = $05
.equ    UDR1            = $03
.equ    UCSR1A          = $02
.equ    UCSR1B          = $01
.equ    UBRR1           = $00

 

;***************************************************************************
;*                             Bit Definitions                             
;***************************************************************************

;* EIMF Register *
.equ    INTF3           = 7
.equ    INTF2           = 6
.equ    INTF1           = 5
.equ    INTF0           = 4
.equ    INT3            = 3
.equ    INT2            = 2
.equ    INT1            = 1
.equ    INT0            = 0

;* SFTCR Register *
.equ    FMXOR           = 3
.equ    WDTS            = 2
.equ    DBG             = 1
.equ    SRST            = 0

;* TIMSK Register *
.equ    TOIE1           = 7
.equ    OCIE1A          = 6
.equ    OCIE1B          = 5
.equ    TOIE2           = 4
.equ    TICIE1          = 3
.equ    OCIE2           = 2
.equ    TOIE0           = 1
.equ    OCIE0           = 0

;* TIFR Register *
.equ    TOV1            = 7
.equ    OCF1A           = 6
.equ    OCF1B           = 5
.equ    TOV2            = 4
.equ    ICF1            = 3
.equ    OCF2            = 2
.equ    TOV0            = 1
.equ    OCF0            = 0

;* TWCR Register *
.equ    TWINT           = 7
.equ    TWEA            = 6
.equ    TWSTA           = 5
.equ    TWSTO           = 4
.equ    TWWC            = 3
.equ    TWEN            = 2
.equ    TWIE            = 0

;* MCUR Register *
.equ    SE              = 5
.equ    SM1             = 4
.equ    SM0             = 3
.equ    PORF            = 2
.equ    WDRF            = 1
.equ    EXTRF           = 0

;* TCCR0 Register *
.equ    FOC0            = 7
.equ    PWM0            = 6
.equ    COM01           = 5
.equ    COM00           = 4
.equ    CTC0            = 3
.equ    CS02            = 2
.equ    CS01            = 1
.equ    CS00            = 0

;* SFIOR Register *
.equ    PSR2            = 1
.equ    PSR10           = 0

;* TCCR1A Register *
.equ    COM1A1          = 7
.equ    COM1A0          = 6
.equ    COM1B1          = 5
.equ    COM1B0          = 4
.equ    FOC1A           = 3
.equ    FOC1B           = 2
.equ    PWM11           = 1
.equ    PWM10           = 0

;* TCCR1B Register *
.equ    ICNC1           = 7
.equ    ICES1           = 6
.equ    ICPE            = 5
.equ    CTC1            = 3
.equ    CS12            = 2
.equ    CS11            = 1
.equ    CS10            = 0

;* TCCR2 Register *
.equ    FOR2            = 7
.equ    PWM2            = 6
.equ    COM21           = 5
.equ    COM20           = 4
.equ    CTC2            = 3
.equ    CS22            = 2
.equ    CS21            = 1
.equ    CS20            = 0

;* ASSR Register *
.equ    AS2             = 3
.equ    TCN2UB          = 2
.equ    OCR2UB          = 1
.equ    TCR2UB          = 0

;* WDTCR Register *
.equ    WDTOE           = 4
.equ    WDE             = 3
.equ    WDP2            = 2
.equ    WDP1            = 1
.equ    WDP0            = 0

;* FISUD Register - Not Available on AT94K05 *
.equ    FIF15           = 7
.equ    FIF14           = 6
.equ    FIF13           = 5
.equ    FIF12           = 4
.equ    FINT15          = 3
.equ    FINT14          = 2
.equ    FINT13          = 1
.equ    FINT12          = 0

;* FISUC Register - Not Available on AT94K05 *
.equ    FIF11           = 7
.equ    FIF10           = 6
.equ    FIF9            = 5
.equ    FIF8            = 4
.equ    FINT11          = 3
.equ    FINT10          = 2
.equ    FINT9           = 1
.equ    FINT8           = 0

;* FISUB Register *
.equ    FIF7            = 7
.equ    FIF6            = 6
.equ    FIF5            = 5
.equ    FIF4            = 4
.equ    FINT7           = 3
.equ    FINT6           = 2
.equ    FINT5           = 1
.equ    FINT4           = 0

;* FISUA Register *
.equ    FIF3            = 7
.equ    FIF2            = 6
.equ    FIF1            = 5
.equ    FIF0            = 4
.equ    FINT3           = 3
.equ    FINT2           = 2
.equ    FINT1           = 1
.equ    FINT0           = 0

;* FISCR Register *
.equ    FIADR           = 7
.equ    XFIS1           = 1
.equ    XFIS0           = 0

;* PORTD Register *
.equ    PD7             = 7
.equ    PD6             = 6
.equ    PD5             = 5
.equ    PD4             = 4
.equ    PD3             = 3
.equ    PD2             = 2
.equ    PD1             = 1
.equ    PD0             = 0

;* DDRD Register *
.equ    DDD7            = 7
.equ    DDD6            = 6
.equ    DDD5            = 5
.equ    DDD4            = 4
.equ    DDD3            = 3
.equ    DDD2            = 2
.equ    DDD1            = 1
.equ    DDD0            = 0

;* PIND Register *
.equ    PIND7           = 7
.equ    PIND6           = 6
.equ    PIND5           = 5
.equ    PIND4           = 4
.equ    PIND3           = 3
.equ    PIND2           = 2
.equ    PIND1           = 1
.equ    PIND0           = 0

;* UCSR0A Register *
.equ    RXC0            = 7
.equ    TXC0            = 6
.equ    UDRE0           = 5
.equ    FE0             = 4
.equ    OR0             = 3
.equ    U2X0            = 1
.equ    MPCM0           = 0

;* UCSR0B Register *
.equ    RXCIE0          = 7
.equ    TXCIE0          = 6
.equ    UDRIE0          = 5
.equ    RXEN0           = 4
.equ    TXEN0           = 3
.equ    CHR90           = 2
.equ    RXB80           = 1
.equ    TXB80           = 0

;* PORTE Register *
.equ    PE7             = 7
.equ    PE6             = 6
.equ    PE5             = 5
.equ    PE4             = 4
.equ    PE3             = 3
.equ    PE2             = 2
.equ    PE1             = 1
.equ    PE0             = 0

;* DDRE Register *
.equ    DDE7            = 7
.equ    DDE6            = 6
.equ    DDE5            = 5
.equ    DDE4            = 4
.equ    DDE3            = 3
.equ    DDE2            = 2
.equ    DDE1            = 1
.equ    DDE0            = 0

;* PINE Register *
.equ    PINE7           = 7
.equ    PINE6           = 6
.equ    PINE5           = 5
.equ    PINE4           = 4
.equ    PINE3           = 3
.equ    PINE2           = 2
.equ    PINE1           = 1
.equ    PINE0           = 0

;* UCSR1A Register *
.equ    RXC1            = 7
.equ    TXC1            = 6
.equ    UDRE1           = 5
.equ    FE1             = 4
.equ    OR1             = 3
.equ    U2X1            = 1
.equ    MPCM1           = 0

;* UCSR1B Register *
.equ    RXCIE1          = 7
.equ    TXCIE1          = 6
.equ    UDRIE1          = 5
.equ    RXEN1           = 4
.equ    TXEN1           = 3
.equ    CHR91           = 2
.equ    RXB81           = 1
.equ    TXB81           = 0

;* XYZ Registers *
.def    XL              = r26
.def    XH              = r27
.def    YL              = r28
.def    YH              = r29
.def    ZL              = r30
.def    ZH              = r31



;***************************************************************************
;*                        Memory Address Definitions                       
;***************************************************************************

.equ    E2END           = $0000
.equ    FLASHEND        = $0000
.equ    RAMEND4K        = $0FFF
.equ    RAMEND8K        = $1FFF
.equ    RAMEND12K       = $2FFF
.equ    RAMEND16K       = $3FFF



;***************************************************************************
;*                       Interrupt Vector Addresses                        
;***************************************************************************

.equ    RESETaddr       = $0000         ;Reset - Program Execution Starts Here
.equ    FPGA_INT0addr   = $0002         ;FPGA Interrupt0
.equ    EXT_INT0addr    = $0004         ;External Interrupt0
.equ    FPGA_INT1addr   = $0006         ;FPGA Interrupt1
.equ    EXT_INT1addr    = $0008         ;External Interrupt1
.equ    FPGA_INT2addr   = $000A         ;FPGA Interrupt2
.equ    EXT_INT2addr    = $000C         ;External Interrupt2
.equ    FPGA_INT3addr   = $000E         ;FPGA Interrupt3
.equ    EXT_INT3addr    = $0010         ;External Interrupt3
.equ    TIM2_COMPaddr   = $0012         ;Timer/Counter2 Compare Match Interrupt
.equ    TIM2_OVFaddr    = $0014         ;Timer/Counter2 Overflow Interrupt
.equ    TIM1_CAPTaddr   = $0016         ;Timer/Counter1 Capture Event Interrupt
.equ    TIM1_COMPAaddr  = $0018         ;Timer/Counter1 Compare Match A Interrupt
.equ    TIM1_COMPBaddr  = $001A         ;Timer/Counter1 Compare Match B Interrupt
.equ    TIM1_OVFaddr    = $001C         ;Timer/Counter1 Overflow Interrupt
.equ    TIM0_COMPaddr   = $001E         ;Timer/Counter0 Compare Match Interrupt
.equ    TIM0_OVFaddr    = $0020         ;Timer/Counter0 Overflow Interrupt
.equ    FPGA_INT4addr   = $0022         ;FPGA Interrupt4
.equ    FPGA_INT5addr   = $0024         ;FPGA Interrupt5
.equ    FPGA_INT6addr   = $0026         ;FPGA Interrupt6
.equ    FPGA_INT7addr   = $0028         ;FPGA Interrupt7
.equ    UART0_RXCaddr   = $002A         ;UART0 Receive Complete Interrupt
.equ    UART0_DREaddr   = $002C         ;UART0 Data Register Empty Interrupt
.equ    UART0_TXCaddr   = $002E         ;UART0 Transmit Complete Interrupt
.equ    FPGA_INT8addr   = $0030         ;FPGA Interrupt8 (Not Available on AT94K05)
.equ    FPGA_INT9addr   = $0032         ;FPGA Interrupt9 (Not Available on AT94K05)
.equ    FPGA_INT10addr  = $0034         ;FPGA Interrupt10 (Not Available on AT94K05)
.equ    FPGA_INT11addr  = $0036         ;FPGA Interrupt11 (Not Available on AT94K05)
.equ    UART1_RXCaddr   = $0038         ;UART1 Receive Complete Interrupt
.equ    UART1_DREaddr   = $003A         ;UART1 Data Register Empty Interrupt
.equ    UART1_TXCaddr   = $003C         ;UART1 Transmit Complete Interrupt
.equ    FPGA_INT12addr  = $003E         ;FPGA Interrupt12 (Not Available on AT94K05)
.equ    FPGA_INT13addr  = $0040         ;FPGA Interrupt13 (Not Available on AT94K05)
.equ    FPGA_INT14addr  = $0042         ;FPGA Interrupt14 (Not Available on AT94K05)
.equ    FPGA_INT15addr  = $0044         ;FPGA Interrupt15 (Not Available on AT94K05)
.equ    TWS_INTaddr     = $0046         ;2-Wire Serial Interrupt