//*** A P P L I C A T I O N   N O T E *************************************
//*
//* Title:               AVR-FPGA Interface Design #3
//* Version:             1.1
//* Last Updated:        October 8, 2001
//* Target:              AT94K05/10/40
//*
//* Support Hotline:     +1 (408) 436-4119
//* Support Email:       fpslic@atmel.com
//*
//*************************************************************************


//*************************************************************************
//*                              Include Files
//*************************************************************************

#include <ioat94k.h>
#include <ina90.h>



//***************************************************************************
//*                             Global Variables
//***************************************************************************

#define sFINT0  0                           //FPGA Interrupt 0 Count SRAM Location
#define sFINT1  1                           //FPGA Interrupt 1 Count SRAM Location

unsigned char rCount0;                      //Count Register for FPGA Interrupt 0
unsigned char rCount1;                      //Count Register for FPGA Interrupt 1

//***************************************************************************
//*                             Interrupt Vectors
//***************************************************************************


//******************************  IAR v1.xx  ********************************
#ifndef __ICCAVR__

#pragma memory = dataseg(LOCATED)
unsigned char DPSRAM[50];                   //Array of "Located" Dual Port SRAM
#pragma memory = default

interrupt [FPGA_INT0] void isr_FPGA_INT0(void)
{
    rCount0 = rCount0 + 1;                  //Increment Count of FPGA Interrupt 0 Calls
    DPSRAM[sFINT0] = rCount0;               //Store FPGA Interrupt Count @ sFINT0
    FISCR &= ~(0x03);                       //Configure FPGA I/O Select Lines
    FISUA = rCount0;                        //Output Data to FPGA via I/O Select 0
}

interrupt [FPGA_INT1] void isr_FPGA_INT1(void)
{
    rCount1 = rCount1 + 1;                  //Increment Count of FPGA Interrupt 1 Calls
    DPSRAM[sFINT1] = rCount1;               //Store FPGA Interrupt Count @ sFINT1
    FISCR &= ~(0x03);                       //Configure FPGA I/O Select Lines
    FISCR |= 0x01;                          //Configure FPGA I/O Select Lines
    FISUA = rCount1;                        //Output Data to FPGA via I/O Select 1
}

#endif // IAR Embedded Workbench v1.xx
//***************************************************************************



//******************************  IAR v2.xx  ********************************
#ifdef __ICCAVR__

#pragma dataseg = LOCATED
__no_init unsigned char DPSRAM[50];         //Array of "Located" Dual Port SRAM
#pragma dataseg = default

#pragma vector = FPGA_INT0
static __interrupt void isr_FPGA_INT0(void)
{
    rCount0 = rCount0 + 1;                  //Increment Count of FPGA Interrupt 0 Calls
    DPSRAM[sFINT0] = rCount0;               //Store FPGA Interrupt Count @ sFINT0
    FISCR = ((0 << XFIS0) | (0 << XFIS1));  //Configure FPGA I/O Select Lines
    FISUA = rCount0;                        //Output Data to FPGA via I/O Select 0
}

#pragma vector = FPGA_INT1
static __interrupt void isr_FPGA_INT1(void)
{
    rCount1 = rCount1 + 1;                  //Increment Count of FPGA Interrupt 1 Calls
    DPSRAM[sFINT1] = rCount1;               //Store FPGA Interrupt Count @ sFINT1
    FISCR = ((1 << XFIS0) | (0 << XFIS1));  //Configure FPGA I/O Select Lines
    FISUA = rCount1;                        //Output Data to FPGA via I/O Select 1
}

#endif /* IAR Embedded Workbench v2.xx */
//***************************************************************************


void initAT94K(void)
{
    _CLI();                                 //Disable Global Interrupts

    rCount0 = 0;                            //Initialize rCount0 = $00

    FISCR |= 0x80;                          //Enable FPGA Interrupt/Mask Access
    FISUA  = 0x03;                          //Enable FPGA Interrupt 0 and Interrupt 1
    FISCR &= ~(0x80);                       //Disable FPGA Interrupt/Mask Access

    _SEI();                                 //Enable Global Interrupts
}


void main(void)
{
    initAT94K();                            //Call initAT94K Function
    while(1);                               //Do Nothing, Wait for an Interrupt
}
