//*** A P P L I C A T I O N   N O T E *************************************
//*
//* Title:               AVR-FPGA Interface Design #3
//* Version:             1.1
//* Last Updated:        October 8, 2001
//* Target:              AT94K05/10/40
//*
//* Support Hotline:     +1 (408) 436-4119
//* Support Email:       fpslic@atmel.com
//*
//*************************************************************************


//*************************************************************************
//*                              Include Files
//*************************************************************************

#include <ioat94k.h>
#include <macros.h>



//***************************************************************************
//*                        Global Variables & Defines
//***************************************************************************

#define sFINT0  0                           //FPGA Interrupt 0 Count SRAM Location
#define sFINT1  1                           //FPGA Interrupt 1 Count SRAM Location


unsigned char rCount0;                      //Count Register for FPGA Interrupt 0
unsigned char rCount1;                      //Count Register for FPGA Interrupt 1


asm(".area memory(abs)\n"                   //The FPGA & AVR within FPSLIC can share
    ".org 0x0F9B\n"                         //the SRAM memory.  The AVR must "locate"
    "_DPSRAM:: .blkb 50");                  //data to be shared with the FPGA.  As of
                                            //October 2001, the only way to locate
                                            //variables in specific locations is to
                                            //use in-line assembly.

extern char DPSRAM[50];                     //Array of "Located" Dual Port SRAM



//***************************************************************************
//*                             Interrupt Vectors
//***************************************************************************

#pragma interrupt_handler isr_FPGA_INT0:FPGA_INT0
#pragma interrupt_handler isr_FPGA_INT1:FPGA_INT1


void isr_FPGA_INT0(void)
{
    rCount0 = rCount0 + 1;                  //Increment Count of FPGA Interrupt 0 Calls
    DPSRAM[sFINT0] = rCount0;               //Store FPGA Interrupt Count @ sFINT0
    FISCR = ((0 << XFIS0) | (0 << XFIS1));  //Configure FPGA I/O Select Lines
    FISUA = rCount0;                        //Output Data to FPGA via I/O Select 0
}


void isr_FPGA_INT1(void)
{
    rCount1 = rCount1 + 1;                  //Increment Count of FPGA Interrupt 1 Calls
    DPSRAM[sFINT1] = rCount1;               //Store FPGA Interrupt Count @ sFINT1
    FISCR = ((1 << XFIS0) | (0 << XFIS1));  //Configure FPGA I/O Select Lines
    FISUA = rCount1;                        //Output Data to FPGA via I/O Select 1
}



void initAT94K(void)
{
    CLI();                                  //Disable Global Interrupts

    rCount0 = 0;                            //Initialize rCount0 = $00
    rCount1 = 0;                            //Initialize rCount1 = $00

    FISCR = (1 << FIADR);                   //Enable FPGA Interrupt/Mask Access
    FISUA = ((1 << FINT0) | (1 << FINT1));  //Enable FPGA Interrupt 0 and Interrupt 1
    FISCR = (0 << FIADR);                   //Disable FPGA Interrupt/Mask Access

    SEI();                                  //Enable Global Interrupts
}


void main(void)
{
    initAT94K();                            //Call initAT94K Function
    while(1);                               //Do Nothing, Wait for an Interrupt
}
